<!-- 自定义封装弹层 -->
<!--尾部按钮具名插槽 footer-->

<!--
参考el-dialog自定义事件
-->

<!--
props值
v-model 是否显示easy-dialog（ 布尔值）
title 标题
appendToBody 是否插入至body
classStyle 自定义类名

其余参考el-dialog自定义属性
-->

<template>
    <el-dialog
        v-if="dialogVisible"
        custom-class="easy-dialog"
        :class="classStyle"
        v-on="$listeners"
        v-bind="$attrs"
        :visible.sync="dialogVisible"
        :show-close="false"
        :top="top"
        :append-to-body="appendToBody"
        close-on-click-modal
    >
        <!-- 装饰 -->
        <div class="decoration" v-if="decoration">
            <slot name="decoration"></slot>
        </div>
        <!-- 关闭图标 -->
        <img
            class="cloes-icon"
            src="@/assets/img/easy-dialog/icon_tck_close@3x.png"
            @click="dialogVisible = false"
        />
        <div class="title-diy">
            <div class="title" v-if="title">{{ title }}</div>
        </div>
        <!-- 内容默认插槽 -->
        <div class="content-diy">
            <slot></slot>
        </div>
        <!-- 尾部按钮插槽 -->
        <div class="footer-diy">
            <slot name="footer"></slot>
        </div>
    </el-dialog>
</template>

<script>
export default {
    name: 'EasyDialog',
    model: {
        prop: 'showEasy',
        event: 'changeDialog',
    },
    props: {
        showEasy: {
            default: false,
            type: Boolean,
        },
        top: {
            default: '10vh',
            type: String,
        },
        title: {
            default: '',
            type: String,
        },
        appendToBody: {
            type: Boolean,
            default: true,
        },
        classStyle: {
            default: '',
            type: String,
        },
        decoration: {
            default: false,
            type: Boolean,
        },
    },
    computed: {
        dialogVisible: {
            get() {
                return this.showEasy
            },
            set(val) {
                this.$emit('changeDialog', val)
            },
        },
    },
}
</script>

<style lang="scss" scoped>
::v-deep .easy-dialog {
  //background: url("~@/assets/images/easy-dialog/dialog-bg.png") no-repeat;
  background-size: 100% 100%;
  box-sizing: border-box;
  border: 1px solid #0273E9;
  background-color: #01215a;
  padding-bottom: 26px;

  .title-diy {
    width: 100%;
    height: 50px;
    display: flex;
    justify-content: center;
    align-items: center;
    // padding-left: 24px;
    box-sizing: border-box;

    .title {
      font-size: 18px;
      font-family: Source Han Sans CN;
      font-weight: 800;
      color: #FFFFFF;
      position: relative;
      text-shadow: 0px 0px 0.83333vw #266bf2;
    }

    .title::after, .title::before {
      content: '';
      position: absolute;
      top: 50%;
      width: 40px;
      height: 4px;
      transform: translateY(-50%);
    }

    .title::before {
      right: calc(100% + 20px);
      background: url('~@/assets/img/bigScreen/line63.png') no-repeat center / 100% 100%;
    }

    .title::after {
      left: calc(100% + 20px);
      background: url('~@/assets/img/bigScreen/line62.png') no-repeat center / 100% 100%;
    }
  }
    .el-dialog__body{
        max-height: 86vh!important
    }
  .content-diy {
    box-sizing: border-box;
    // max-height: calc(900px - 44px - 30px);
    overflow-y: hidden;
    padding: 0 24px;
    box-sizing: border-box;
    /* 设置滚动条的样式 */
    &::-webkit-scrollbar {
        width: 8px !important; //垂直方向上的宽
        height: 8px !important; //水平方向上的宽
    }
    
    /* 滚动槽 */
    &::-webkit-scrollbar-track {
        border-radius: 0;
        background-color: #01215a !important;
    }
    
    /* 滚动条滑块 */
    &::-webkit-scrollbar-thumb {
        border-radius: 18px;
        background-color: rgba(#fff, 0.1) !important;
    }
    &/*滚动条交叉样式*/
    ::-webkit-scrollbar-corner {
        background: #01215a !important;
    }
  }

  .footer-diy {
    display: flex;
    justify-content: center;
  }

  .el-dialog__header {
    width: 0;
    height: 0;
    padding: 0;
  }

  .el-dialog__body {
    padding: 0;
  }

  .cloes-icon {
    width: 20px;
    height: 20px;
    position: absolute;
    top: 6px;
    right: 6px;
    cursor: pointer;
  }
  .decoration{
    width: 100%;
    height: 100%;
    position: absolute;
    left: 0;
    top: 0;
  }
}
</style>
